@@ -1,4 +1,4 @@
-//$Id: deriveddialog.cc,v 1.1 2002/11/05 13:51:39 murrayc Exp $ -*- c++ -*-
+//$Id: deriveddialog.cc,v 1.2 2004/02/13 17:10:41 murrayc Exp $ -*- c++ -*-
 
 /* libglademm example Copyright (C) 2003 libglademm development team
  *
@@ -27,7 +27,7 @@ DerivedDialog::DerivedDialog(BaseObjectType* cobject, const Glib::RefPtr<Gnome::
   m_refGlade->get_widget("quit_button", m_pButton);
   if(m_pButton)
   {
-    m_pButton->signal_clicked().connect( SigC::slot(*this, &DerivedDialog::on_button_quit) ); 
+    m_pButton->signal_clicked().connect( sigc::mem_fun(*this, &DerivedDialog::on_button_quit) ); 
   }
 }
 
